@@ -1,6 +1,6 @@
 package Mason::Interp;
 BEGIN {
-  $Mason::Interp::VERSION = '2.07';
+  $Mason::Interp::VERSION = '2.08';
 }
 use Carp;
 use Devel::GlobalDestruction;
@@ -13,7 +13,7 @@ use Mason::Request;
 use Mason::Result;
 use Mason::Types;
 use Mason::Util
-  qw(catdir catfile combine_similar_paths find_wanted first_index is_absolute json_decode mason_canon_path read_file touch_file uniq write_file);
+  qw(catdir catfile combine_similar_paths find_wanted first_index is_absolute json_decode mason_canon_path read_file taint_is_on touch_file uniq write_file);
 use Memoize;
 use Moose::Util::TypeConstraints;
 use Mason::Moose;
@@ -431,12 +431,10 @@ method _load_class_from_object_file ( $compc, $object_file, $path, $default_pare
       || ( $default_parent_path eq '/' && $self->component_class )
       || $self->load($default_parent_path);
 
-    eval(
-        sprintf(
-            'package %s; use Moose; extends "%s"; do("%s"); die $@ if $@',
-            $compc, $parent_compc, $object_file
-        )
-    );
+    my $code = sprintf( 'package %s; use Moose; extends "%s"; do("%s"); die $@ if $@',
+        $compc, $parent_compc, $object_file );
+    ($code) = ( $code =~ /^(.*)/s ) if taint_is_on();
+    eval($code);
     die $@ if $@;
 
     $compc->_set_class_cmeta($self);
