@@ -1,6 +1,6 @@
 package Mason::Request;
 BEGIN {
-  $Mason::Request::VERSION = '2.07';
+  $Mason::Request::VERSION = '2.08';
 }
 use Carp;
 use File::Basename;
@@ -73,20 +73,8 @@ method add_cleanup ($code) {
     push( @{ $self->{cleanups} }, $code );
 }
 
-method apply_filter ($filter, $yield) {
-    my $filtered_output;
-    $yield = sub { $yield }
-      if !ref($yield);
-    if ( ref($filter) eq 'CODE' ) {
-        $filtered_output = $filter->( $yield->() );
-    }
-    elsif ( blessed($filter) && $filter->can('apply_filter') ) {
-        $filtered_output = $filter->apply_filter($yield);
-    }
-    else {
-        die "'$filter' is neither a code ref nor a filter object";
-    }
-    return $filtered_output;
+method cache () {
+    die 'caching is now in the cache plugin (Mason::Plugin::Cache)';
 }
 
 method capture ($code) {
@@ -143,6 +131,10 @@ method decline () {
     $self->clear_and_abort;
 }
 
+method filter () {
+    $self->_apply_filters(@_);
+}
+
 method flush_buffer () {
     my $request_buffer = $self->_request_buffer;
     $self->out_method->( $$request_buffer, $self )
@@ -344,23 +336,47 @@ method with_tied_print ($code) {
 # PRIVATE METHODS
 #
 
-method _apply_filters ($filters, $yield) {
-    if ( !@$filters ) {
+method _apply_one_filter ($filter, $yield) {
+    my $filtered_output;
+    if ( ref($yield) ne 'CODE' ) {
+        my $orig_yield = $yield;
+        $yield = sub { $orig_yield };
+    }
+    if ( ref($filter) eq 'CODE' ) {
+        local $_ = $yield->();
+        $filtered_output = $filter->($_);
+    }
+    elsif ( blessed($filter) && $filter->can('apply_filter') ) {
+        $filtered_output = $filter->apply_filter($yield);
+    }
+    else {
+        die "'$filter' is neither a code ref nor a filter object";
+    }
+    return $filtered_output;
+}
+
+method _apply_filters () {
+    my $yield = pop(@_);
+    if ( ref($yield) ne 'CODE' ) {
+        my $orig_yield = $yield;
+        $yield = sub { $orig_yield };
+    }
+    if ( !@_ ) {
         return $yield->();
     }
     else {
-        my @filters = @$filters;
-        my $filter  = pop(@filters);
-        return $self->_apply_filters( \@filters, sub { $self->apply_filter( $filter, $yield ) } );
+        my $filter = pop(@_);
+        return $self->_apply_filters( @_, sub { $self->_apply_one_filter( $filter, $yield ) } );
     }
 }
 
-method _apply_filters_to_output ($filters, $output_method) {
-    my $yield = sub {
+method _apply_filters_to_output () {
+    my $output_method = pop(@_);
+    my $yield         = sub {
         my @args = @_;
         $self->capture( sub { $output_method->(@args) } );
     };
-    my $filtered_output = $self->_apply_filters( $filters, $yield );
+    my $filtered_output = $self->_apply_filters( @_, $yield );
     $self->print($filtered_output);
 }
 
@@ -585,6 +601,10 @@ C</dhandler.mc>, and a third would throw a "not found" error.
 
 =for html <a name="flush_buffer" />
 
+=item filter (filter_expr, [filter_expr...], string|coderef)
+
+Applies one or more filters to a string or to a coderef that returns a string.
+
 =item flush_buffer ()
 
 Flushes the main output buffer. Anything currently in the buffer is sent to the
